==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/ga.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Aitheantas Néil Cónaidhme neamhbhailí",
    "Server to server sharing is not enabled on this server" : "Níl comhroinnt freastalaí le freastalaí cumasaithe ar an bhfreastalaí seo",
    "Couldn't establish a federated share." : "Níorbh fhéidir sciar cónasctha a bhunú.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Níorbh fhéidir sciar chónaidhme a bhunú, b'fhéidir go raibh an pasfhocal mícheart.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Iarratas Comhroinnte Cónaidhme seolta, gheobhaidh tú cuireadh. Seiceáil d'fhógraí.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Níorbh fhéidir sciar cónasctha a bhunú, tá an chuma ar an scéal go bhfuil an freastalaí chun cónascadh leis ró-shean (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Níl sé ceadaithe scaireanna grúpa cónasctha a sheoladh ón bhfreastalaí seo.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Theip ar chomhroinnt %1$s, toisc go bhfuil an mhír seo roinnte cheana leis an gcuntas %2$s",
    "Not allowed to create a federated share to the same account" : "Ní cheadaítear sciar cónasctha a chruthú sa chuntas céanna",
    "Federated shares require read permissions" : "Teastaíonn ceadanna léite chun scaireanna cónasctha",
    "File is already shared with %s" : "Tá an comhad roinnte le %scheana féin",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Theip ar chomhroinnt %1$s, níorbh fhéidir %2$s a aimsiú, b'fhéidir nach féidir teacht ar an bhfreastalaí faoi láthair nó go n-úsáideann sé teastas féin-shínithe.",
    "Could not find share" : "Níorbh fhéidir sciar a aimsiú",
    "Federated sharing" : "Comhroinnt chónaidhme",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Fuair ​​tú {share} mar sciar cianda ó {user} (ar son {behalf})",
    "You received {share} as a remote share from {user}" : "Fuair ​​tú {share} mar sciar cianda ó {user}",
    "Accept" : "Glac",
    "Decline" : "Meath",
    "Federated Cloud Sharing" : "Comhroinnt Scamall Cónaidhme",
    "Sharing" : "Roinnt",
    "Federated file sharing" : "Comhroinnt chónaidhme",
    "Provide federated file sharing across servers" : "Comhroinnt comhad cónasctha a sholáthar thar freastalaithe",
    "Confirm data upload to lookup server" : "Deimhnigh uaslódáil sonraí chuig an bhfreastalaí cuardaigh",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Nuair a bheidh sé cumasaithe, déanfar gach maoin chuntais (m.sh. seoladh ríomhphoist) a bhfuil scóip infheictheachta aici “foilsithe”, a shioncronú go huathoibríoch agus a tharchur chuig córas seachtrach agus cuirfear ar fáil iad i leabhar seoltaí poiblí domhanda.",
    "Disable upload" : "Díchumasaigh uaslódáil",
    "Enable data upload" : "Cumasaigh uaslódáil sonraí",
    "Confirm querying lookup server" : "Deimhnigh an freastalaí cuardaigh fiosraithe",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Nuair a bheidh sé cumasaithe, seolfar an t-ionchur cuardaigh agus scaireanna á gcruthú chuig córas seachtrach a sholáthraíonn leabhar seoltaí poiblí agus domhanda.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Úsáidtear é seo chun an ID scamall cónasctha a aisghabháil chun comhroinnt chónasctha a dhéanamh níos éasca.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Ina theannta sin, d’fhéadfaí seoltaí ríomhphoist úsáideoirí a sheoladh chuig an gcóras sin chun iad a fhíorú.",
    "Disable querying" : "Díchumasaigh an cheistiú",
    "Enable querying" : "Cumasaigh fiosrú",
    "Unable to update federated files sharing config" : "Ní féidir an chumraíocht chomhroinnte comhad a nuashonrú",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Coigeartaigh conas is féidir le daoine roinnt idir freastalaithe. Áirítear leis seo scaireanna idir daoine ar an bhfreastalaí seo freisin má tá comhroinnt chónaidhmeach á úsáid acu.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Lig do dhaoine ar an bhfreastalaí seo scaireanna a sheoladh chuig freastalaithe eile ( ceadaíonn an rogha seo rochtain WebDAV ar scaireanna poiblí freisin)",
    "Allow people on this server to receive shares from other servers" : "Lig do dhaoine ar an bhfreastalaí seo scaireanna a fháil ó fhreastalaithe eile",
    "Allow people on this server to send shares to groups on other servers" : "Lig do dhaoine ar an bhfreastalaí seo scaireanna a sheoladh chuig grúpaí ar fhreastalaithe eile",
    "Allow people on this server to receive group shares from other servers" : "Lig do dhaoine ar an bhfreastalaí seo scaireanna grúpa a fháil ó fhreastalaithe eile",
    "The lookup server is only available for global scale." : "Níl an freastalaí cuardaigh ar fáil ach do scála domhanda.",
    "Search global and public address book for people" : "Cuardaigh leabhar seoltaí domhanda agus poiblí do dhaoine",
    "Allow people to publish their data to a global and public address book" : "Lig do dhaoine a gcuid sonraí a fhoilsiú i leabhar aitheasc domhanda agus poiblí",
    "Trusted federation" : "Cónaidhm iontaofa",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Glac go huathoibríoch le scaireanna ó chuntais chónaidhme iontaofa agus ó ghrúpaí de réir réamhshocraithe",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Roinn liom trí m'aitheantas scamall #Nextcloud Federated Cloud, féach {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Roinn liom trí m'aitheantas scamall #Nextcloud Federated Cloud",
    "Share with me via Nextcloud" : "Roinn liom trí Nextcloud",
    "Cloud ID copied to the clipboard" : "Cóipeáladh Cloud ID chuig an ngearrthaisce",
    "Copy to clipboard" : "Cóipeáil chuig an ngearrthaisce",
    "Clipboard not available. Please copy the cloud ID manually." : "Níl an gearrthaisce ar fáil. Cóipeáil an t-aitheantas néil de láimh.",
    "Copied!" : "Cóipeáladh!",
    "Federated Cloud" : "Scamall Cónaidhme",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Is féidir leat a roinnt le duine ar bith a úsáideann freastalaí Nextcloud nó freastalaithe agus seirbhísí comhoiriúnacha Open Cloud Mesh (OCM) eile! Níl le déanamh ach a n-ID Cloud Cónaidhme a chur sa dialóg scaireanna. Breathnaíonn sé cosúil le person@cloud.example.com",
    "Your Federated Cloud ID" : "D'Aitheantas Néal Cónaidhmeach",
    "Share it so your friends can share files with you:" : "Roinn é ionas gur féidir le do chairde comhaid a roinnt leat:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (Twitter roimhe seo)",
    "formerly Twitter" : "Twitter roimhe seo",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Cuir le do láithreán gréasáin",
    "HTML Code:" : "Cód HTML:",
    "Cancel" : "Cealaigh",
    "Add remote share" : "Cuir cianroinnte leis",
    "Remote share" : "Comhroinnt iargúlta",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ar mhaith leat an sciar cianda {name} ó {owner}@{remote} a chur leis?",
    "Remote share password" : "Pasfhocal comhroinnte cianda",
    "Incoming share could not be processed" : "Níorbh fhéidir an sciar isteach a phróiseáil"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/ga.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Aitheantas Néil Cónaidhme neamhbhailí",
    "Server to server sharing is not enabled on this server" : "Níl comhroinnt freastalaí le freastalaí cumasaithe ar an bhfreastalaí seo",
    "Couldn't establish a federated share." : "Níorbh fhéidir sciar cónasctha a bhunú.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Níorbh fhéidir sciar chónaidhme a bhunú, b'fhéidir go raibh an pasfhocal mícheart.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Iarratas Comhroinnte Cónaidhme seolta, gheobhaidh tú cuireadh. Seiceáil d'fhógraí.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Níorbh fhéidir sciar cónasctha a bhunú, tá an chuma ar an scéal go bhfuil an freastalaí chun cónascadh leis ró-shean (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Níl sé ceadaithe scaireanna grúpa cónasctha a sheoladh ón bhfreastalaí seo.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Theip ar chomhroinnt %1$s, toisc go bhfuil an mhír seo roinnte cheana leis an gcuntas %2$s",
    "Not allowed to create a federated share to the same account" : "Ní cheadaítear sciar cónasctha a chruthú sa chuntas céanna",
    "Federated shares require read permissions" : "Teastaíonn ceadanna léite chun scaireanna cónasctha",
    "File is already shared with %s" : "Tá an comhad roinnte le %scheana féin",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Theip ar chomhroinnt %1$s, níorbh fhéidir %2$s a aimsiú, b'fhéidir nach féidir teacht ar an bhfreastalaí faoi láthair nó go n-úsáideann sé teastas féin-shínithe.",
    "Could not find share" : "Níorbh fhéidir sciar a aimsiú",
    "Federated sharing" : "Comhroinnt chónaidhme",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Fuair ​​tú {share} mar sciar cianda ó {user} (ar son {behalf})",
    "You received {share} as a remote share from {user}" : "Fuair ​​tú {share} mar sciar cianda ó {user}",
    "Accept" : "Glac",
    "Decline" : "Meath",
    "Federated Cloud Sharing" : "Comhroinnt Scamall Cónaidhme",
    "Sharing" : "Roinnt",
    "Federated file sharing" : "Comhroinnt chónaidhme",
    "Provide federated file sharing across servers" : "Comhroinnt comhad cónasctha a sholáthar thar freastalaithe",
    "Confirm data upload to lookup server" : "Deimhnigh uaslódáil sonraí chuig an bhfreastalaí cuardaigh",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Nuair a bheidh sé cumasaithe, déanfar gach maoin chuntais (m.sh. seoladh ríomhphoist) a bhfuil scóip infheictheachta aici “foilsithe”, a shioncronú go huathoibríoch agus a tharchur chuig córas seachtrach agus cuirfear ar fáil iad i leabhar seoltaí poiblí domhanda.",
    "Enable data upload" : "Cumasaigh uaslódáil sonraí",
    "Disable upload" : "Díchumasaigh uaslódáil",
    "Confirm querying lookup server" : "Deimhnigh an freastalaí cuardaigh fiosraithe",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Nuair a bheidh sé cumasaithe, seolfar an t-ionchur cuardaigh agus scaireanna á gcruthú chuig córas seachtrach a sholáthraíonn leabhar seoltaí poiblí agus domhanda.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Úsáidtear é seo chun an ID scamall cónasctha a aisghabháil chun comhroinnt chónasctha a dhéanamh níos éasca.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Ina theannta sin, d’fhéadfaí seoltaí ríomhphoist úsáideoirí a sheoladh chuig an gcóras sin chun iad a fhíorú.",
    "Enable querying" : "Cumasaigh fiosrú",
    "Disable querying" : "Díchumasaigh an cheistiú",
    "Unable to update federated files sharing config" : "Ní féidir an chumraíocht chomhroinnte comhad a nuashonrú",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Coigeartaigh conas is féidir le daoine roinnt idir freastalaithe. Áirítear leis seo scaireanna idir daoine ar an bhfreastalaí seo freisin má tá comhroinnt chónaidhmeach á úsáid acu.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Lig do dhaoine ar an bhfreastalaí seo scaireanna a sheoladh chuig freastalaithe eile ( ceadaíonn an rogha seo rochtain WebDAV ar scaireanna poiblí freisin)",
    "Allow people on this server to receive shares from other servers" : "Lig do dhaoine ar an bhfreastalaí seo scaireanna a fháil ó fhreastalaithe eile",
    "Allow people on this server to send shares to groups on other servers" : "Lig do dhaoine ar an bhfreastalaí seo scaireanna a sheoladh chuig grúpaí ar fhreastalaithe eile",
    "Allow people on this server to receive group shares from other servers" : "Lig do dhaoine ar an bhfreastalaí seo scaireanna grúpa a fháil ó fhreastalaithe eile",
    "The lookup server is only available for global scale." : "Níl an freastalaí cuardaigh ar fáil ach do scála domhanda.",
    "Search global and public address book for people" : "Cuardaigh leabhar seoltaí domhanda agus poiblí do dhaoine",
    "Allow people to publish their data to a global and public address book" : "Lig do dhaoine a gcuid sonraí a fhoilsiú i leabhar aitheasc domhanda agus poiblí",
    "Trusted federation" : "Cónaidhm iontaofa",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Glac go huathoibríoch le scaireanna ó chuntais chónaidhme iontaofa agus ó ghrúpaí de réir réamhshocraithe",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Roinn liom trí m'aitheantas scamall #Nextcloud Federated Cloud, féach {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Roinn liom trí m'aitheantas scamall #Nextcloud Federated Cloud",
    "Share with me via Nextcloud" : "Roinn liom trí Nextcloud",
    "Cloud ID copied" : "Aitheantas Cloud cóipeáilte",
    "Copy" : "Cóipeáil",
    "Clipboard not available. Please copy the cloud ID manually." : "Níl an gearrthaisce ar fáil. Cóipeáil an t-aitheantas néil de láimh.",
    "Copied!" : "Cóipeáladh!",
    "Federated Cloud" : "Scamall Cónaidhme",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Is féidir leat comhroinnt le duine ar bith a úsáideann freastalaí {productName} nó freastalaithe agus seirbhísí eile atá comhoiriúnach le Open Cloud Mesh (OCM)! Cuir a n-ID Cónaidhme Cloud sa dialóg comhroinnte. Tá cuma person@cloud.example.com air.",
    "Your Federated Cloud ID" : "D'Aitheantas Néal Cónaidhmeach",
    "Share it so your friends can share files with you:" : "Roinn é ionas gur féidir le do chairde comhaid a roinnt leat:",
    "Bluesky" : "Bluesky",
    "Facebook" : "Facebook",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Cuir le do láithreán gréasáin",
    "Share with me via {productName}" : "Roinn liom trí {productName}",
    "HTML Code:" : "Cód HTML:",
    "Cancel" : "Cealaigh",
    "Add remote share" : "Cuir cianroinnte leis",
    "Remote share" : "Comhroinnt iargúlta",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ar mhaith leat an sciar cianda {name} ó {owner}@{remote} a chur leis?",
    "Remote share password" : "Pasfhocal comhroinnte cianda",
    "Incoming share could not be processed" : "Níorbh fhéidir an sciar isteach a phróiseáil",
    "Cloud ID copied to the clipboard" : "Cóipeáladh Cloud ID chuig an ngearrthaisce",
    "Copy to clipboard" : "Cóipeáil chuig an ngearrthaisce",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Is féidir leat a roinnt le duine ar bith a úsáideann freastalaí Nextcloud nó freastalaithe agus seirbhísí comhoiriúnacha Open Cloud Mesh (OCM) eile! Níl le déanamh ach a n-ID Cloud Cónaidhme a chur sa dialóg scaireanna. Breathnaíonn sé cosúil le person@cloud.example.com",
    "X (formerly Twitter)" : "X (Twitter roimhe seo)",
    "formerly Twitter" : "Twitter roimhe seo"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
